@@ -10,8 +10,8 @@ SEXP showtext_end();
 static R_CallMethodDef call_methods[] = {
     {"showtext_new_outline_funs",    (DL_FUNC) &showtext_new_outline_funs,    0},
     {"showtext_cairo_device_bitmap", (DL_FUNC) &showtext_cairo_device_bitmap, 0},
-    {"showtext_begin",               (DL_FUNC) &showtext_begin,               1},
-    {"showtext_end",                 (DL_FUNC) &showtext_end,                 0},
+    {"showtext_begin_c",             (DL_FUNC) &showtext_begin,               1},
+    {"showtext_end_c",               (DL_FUNC) &showtext_end,                 0},
     {NULL, NULL, 0}
 };
 
